sequencetools.repeat_runs_in_sequence_to_count
==============================================

.. autofunction:: abjad.tools.sequencetools.repeat_runs_in_sequence_to_count.repeat_runs_in_sequence_to_count
